#
# spec file for package ldb
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{!?py3_soflags:  %global py3_soflags cpython-%{python3_version_nodots}m}
%{!?py3_soflags_dash:   %global py3_soflags_dash %(echo %{py3_soflags} | sed "s/_/-/g")}

%global with_lmdb 0
%if 0%{?suse_version} > 1320
%ifarch x86_64
%global with_lmdb 1
%endif
%endif

%define lmdb_version 0.9.16
%define talloc_version 2.3.3
%define tdb_version 1.4.4
%define tevent_version 0.11.0

Name:           ldb
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  doxygen
%if 0%{?suse_version} > 1500
%ifnarch ppc
BuildRequires:  libcmocka-devel >= 1.1.3
%endif
%endif
BuildRequires:  libtalloc-devel >= %{talloc_version}
BuildRequires:  libtdb-devel >= %{tdb_version}
BuildRequires:  libtevent-devel >= %{tevent_version}
BuildRequires:  libxslt
BuildRequires:  popt-devel
BuildRequires:  python3-devel
BuildRequires:  python3-talloc >= %{talloc_version}
BuildRequires:  python3-talloc-devel >= %{talloc_version}
BuildRequires:  python3-tdb >= %{tdb_version}
BuildRequires:  python3-tevent >= %{tevent_version}
%if 0%{?suse_version} >= 1330
BuildRequires:  libtirpc-devel
%endif
%if %{with_lmdb}
BuildRequires:  lmdb-devel >= %{lmdb_version}
%endif

URL:            https://ldb.samba.org/
Version:        2.4.4
Release:        150400.4.11.1
Summary:        An LDAP-like embedded database
License:        LGPL-3.0-or-later
Group:          Development/Libraries/C and C++
Source:         https://download.samba.org/pub/ldb/ldb-%{version}.tar.gz
Source1:        https://download.samba.org/pub/ldb/ldb-%{version}.tar.asc
Source2:        ldb.keyring
Source4:        baselibs.conf
Patch0:         ldb-python3.5-fix-soabi_name.patch
Patch1:         cve-2023-0614.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
LDB is an LDAP-like embedded database.

%package -n libldb2
Summary:        An LDAP-like embedded database
Group:          System/Libraries
Obsoletes:      libldb1 < %{version}

%description -n libldb2
LDB is an LDAP-like embedded database.

This package includes the ldb2 library.

%package -n libldb-devel
Summary:        Libraries and Header Files to Develop Programs with ldb2 Support
Group:          Development/Libraries/C and C++
Requires:       libldb2 = %{version}
Requires:       pkg-config

%description -n libldb-devel
LDB is an LDAP-like embedded database.

Libraries and Header Files to Develop Programs with ldb2 Support.

%package -n ldb-tools
Summary:        Tools to manipulate LDB files
Group:          Development/Libraries/C and C++

%description -n ldb-tools
Tools to manipulate LDB files.

%package -n python3-ldb
Summary:        Python3 bindings for the LDB library
Group:          Development/Libraries/Python
Requires:       libldb2 = %{version}
Obsoletes:      python-ldb

%description -n python3-ldb
This package contains the python3 bindings for the LDB library.

%package -n python3-ldb-devel
Summary:        Development files for the Python3 bindings for the LDB library
Group:          Development/Libraries/Python
Requires:       pkg-config
Requires:       python3-ldb = %{version}
Obsoletes:      python-ldb-devel

%description -n python3-ldb-devel
This package contains the development files for the Python bindings for the
LDB library.

%prep
%setup -n ldb-%{version} -q
%autopatch -p1

%build
%if 0%{?suse_version} > 1110
	export SUSE_ASNEEDED=0
%endif
export CFLAGS="%{optflags} -D_GNU_SOURCE -D_LARGEFILE64_SOURCE -DIDMAP_RID_SUPPORT_TRUSTED_DOMAINS"
%define bundled_libs cmocka
%if 0%{?suse_version} > 1500
%ifnarch ppc
	%define bundled_libs NONE
%endif
%endif

export CFLAGS="%{optflags} -D_GNU_SOURCE -D_LARGEFILE64_SOURCE -DIDMAP_RID_SUPPORT_TRUSTED_DOMAINS"
CONFIGURE_OPTIONS="\
	--prefix=%{_prefix} \
	--libdir=%{_libdir} \
	--disable-rpath \
	--disable-rpath-install \
	--disable-silent-rules \
	--with-modulesdir=%{_libdir}/ldb2/modules \
	--with-privatelibdir=%{_libdir}/ldb2 \
	--bundled-libraries=%{bundled_libs} \
	--builtin-libraries=replace \
%if !%{with_lmdb}
	--without-ldb-lmdb \
%endif
"
./configure ${CONFIGURE_OPTIONS}
make %{?_smp_mflags} \
	all
doxygen Doxyfile
# remove man page with bogus full build dir in path
rm -f apidocs/man/man3/_*_ldb-%{version}_include_.3

%check
%if %{with_lmdb}
LD_LIBRARY_PATH="bin/shared:bin/shared/private" \
LDB_MODULES_PATH="bin/modules" \
make test
%endif

%install
%make_install

# Install API documentation
cp -a apidocs/man/* %{buildroot}/%{_mandir}

sed -i 's;-lpyldb-util.%{py3_soflags_dash};-lpyldb-util.%{py3_soflags};g' %{buildroot}/%{_libdir}/pkgconfig/pyldb-util.%{py3_soflags}.pc

%post -n libldb2 -p /sbin/ldconfig

%postun -n libldb2 -p /sbin/ldconfig

%post -n python3-ldb -p /sbin/ldconfig

%postun -n python3-ldb -p /sbin/ldconfig

%files -n libldb2
%defattr(-,root,root)
%{_libdir}/libldb.so.2*
%dir %{_libdir}/ldb2
%{_libdir}/ldb2/libldb-key-value.so
%{_libdir}/ldb2/libldb-tdb-err-map.so
%{_libdir}/ldb2/libldb-tdb-int.so
%dir %{_libdir}/ldb2/modules
%dir %{_libdir}/ldb2/modules/ldb
%{_libdir}/ldb2/modules/ldb/asq.so
%{_libdir}/ldb2/modules/ldb/paged_searches.so
%{_libdir}/ldb2/modules/ldb/rdn_name.so
%{_libdir}/ldb2/modules/ldb/sample.so
%{_libdir}/ldb2/modules/ldb/server_sort.so
%{_libdir}/ldb2/modules/ldb/skel.so
%{_libdir}/ldb2/modules/ldb/tdb.so
%{_libdir}/ldb2/modules/ldb/ldb.so
%if 0%{?suse_version} <= 1500
%{_libdir}/ldb2/libcmocka-ldb.so
%endif
%ifarch ppc
%{_libdir}/ldb2/libcmocka-ldb.so
%endif
%if %{with_lmdb}
%{_libdir}/ldb2/libldb-mdb-int.so
%{_libdir}/ldb2/modules/ldb/mdb.so
%endif

%files -n libldb-devel
%defattr(-,root,root)
%{_includedir}/ldb.h
%{_includedir}/ldb_errors.h
%{_includedir}/ldb_handlers.h
%{_includedir}/ldb_module.h
%{_includedir}/ldb_version.h
%{_libdir}/libldb.so
%{_libdir}/pkgconfig/ldb.pc
%{_mandir}/man3/ldb*.3.*
%{_mandir}/man3/ldif*.3.*

%files -n ldb-tools
%defattr(-,root,root)
%{_bindir}/ldbadd
%{_bindir}/ldbdel
%{_bindir}/ldbedit
%{_bindir}/ldbmodify
%{_bindir}/ldbrename
%{_bindir}/ldbsearch
%{_libdir}/ldb2/libldb-cmdline.so
%{_mandir}/man1/ldbadd.1.*
%{_mandir}/man1/ldbdel.1.*
%{_mandir}/man1/ldbedit.1.*
%{_mandir}/man1/ldbmodify.1.*
%{_mandir}/man1/ldbrename.1.*
%{_mandir}/man1/ldbsearch.1.*

%files -n python3-ldb
%defattr(-,root,root)
%{_libdir}/libpyldb-util.%{py3_soflags}.so.*
%{python3_sitearch}/_ldb_text.py
%if 0%{?centos_version} > 599 || 0%{?fedora_version} > 11 || 0%{?rhel_version} > 599
%{python3_sitearch}/__pycache__/_ldb_text.cpython-*.py[co]
%endif
%{python3_sitearch}/ldb.%{py3_soflags}.so

%files -n python3-ldb-devel
%defattr(-,root,root)
%{_includedir}/pyldb.h
%{_libdir}/libpyldb-util.%{py3_soflags}.so
%{_libdir}/pkgconfig/pyldb-util.%{py3_soflags}.pc
%{_mandir}/man3/PyLdb*.3.*

%changelog
* Thu Mar 23 2023 nopower@suse.com
- Remove no longer needed ldb-memory-bug-15096-4.15-ldbonly.patch
- Add cve-2023-0614.patch: Address CVE-2023-0614
- CVE-2023-0614: samba: Access controlled AD LDAP attributes can be
  discovered; (bsc#1209485); (bso#15270);
- Update to version 2.4.4
  + CVE-2022-32746 ldb: db: Use-after-free occurring in
    database audit logging module; (bso#15009); (bsc#1201490).
* Fri Jul 15 2022 nopower@suse.com
- Add ldb-memory-bug-15096-4.15-ldbonly.patch to backport all
  changes for ldb-2.4.4.
  + CVE-2022-32746: samba: ldb: Use-after-free occurring in
    database audit logging module; (bso#15009); (bsc#1201490).
* Fri Jul  8 2022 scabrero@suse.de
- Update to version 2.4.3
  + Fix build problems, waf produces incorrect names for python
    extensions; (bso#15071);
* Wed Apr  6 2022 scabrero@suse.de
- Update to version 2.4.2
  + Fix for CVE-2021-3670, ensure that the LDB request has not
    timed out during filter processing as the LDAP server
    MaxQueryDuration is otherwise not honoured.
* Tue Jan 11 2022 scabrero@suse.de
- Modify packaging to allow parallel installation with libldb1
  (bsc#1192684):
  + Private libraries are installed in %%{_libdir}/ldb2/
  + Modules are installed in %%{_libdir}/ldb2/modules
* Wed Nov 10 2021 scabrero@suse.de
- Update to version 2.4.1
  + Corrected python behaviour for 'in' for LDAP attributes
    contained as part of ldb.Message; (bso#14845);
  + Fix memory handling in ldb.msg_diff; (bso#14836);
  + Corrected python docstrings
* Fri Sep 17 2021 scabrero@suse.de
- Update to version 2.4.0
  + Improve calculate_popt_array_length()
  + Use C99 initializers for builtin_popt_options[]
  + pyldb: Fix Message.items() for a message containing elements
  + pyldb: Add test for Message.items()
  + tests: Use ldbsearch '--scope instead of '-s'
  + pyldb: fix a typo
  + Change page size of guidindexpackv1.ldb
  + Use a 1MiB lmdb so the test also passes on aarch64 CentOS stream
  + attrib_handler casefold: simplify space dropping
  + fix ldb_comparison_fold off-by-one overrun
  + CVE-2020-27840: pytests: move Dn.validate test to ldb
  + CVE-2020-27840 ldb_dn: avoid head corruption in ldb_dn_explode
  + CVE-2021-20277 ldb/attrib_handlers casefold: stay in bounds
  + CVE-2021-20277 ldb tests: ldb_match tests with extra spaces
  + improve comments for ldb_module_connect_backend()
  + test/ldb_tdb: correct introductory comments
  + ldb.h: remove undefined async_ctx function signatures
  + correct comments in attrib_handers val_to_int64
  + dn tests use cmocka print functions
  + ldb_match: remove redundant check
  + add tests for ldb_wildcard_compare
  + ldb_match: trailing chunk must match end of string
  + pyldb: catch potential overflow error in py_timestring
  + ldb: remove some 'if PY3's in tests
  + Add missing break in switch statement
* Wed Mar 31 2021 scabrero@suse.de
- Update to ldb 2.3.0
* Wed Mar 24 2021 nopower@suse.com
- Release ldb 2.2.1
  + CVE-2020-27840: samba: Unauthenticated remote heap corruption
    via bad DNs; (bso#14595); (bsc#1183572).
  + CVE-2021-20277: samba: out of bounds read in ldb_handler_fold;
    (bso#14655); (bsc#1183574).
* Mon Oct 12 2020 dimstar@opensuse.org
- Remove old if suse_version != 1110 || arch != i386 construct:
  unlikely the current package ever builds for 1110 && 386.
* Fri Sep 11 2020 ddiss@suse.com
- Release ldb 2.2.0
  + Fix memory leak in ldb_kv_index_dn_ordered(); (bso#14299)
  + Fix off-by-one increment in lldb_add_msg_attr; (bso#14413)
* Fri Jul  3 2020 nopower@suse.com
- Release ldb 2.1.4
  + CVE-2020-10730: NULL de-reference in AD DC LDAP server when
    ASQ and VLV combined; (bso#14364); (bsc#1173159)
* Wed May 20 2020 david.mulder@suse.com
  ldb: Bump version to 2.1.3; (bso#14330)
* Tue Apr 28 2020 nopower@suse.com
- Release ldb 2.1.2
  + CVE-2020-10700: ldb: Always use ldb_next_request() in
    ASQ module; ;(bso#14331); (bsc#1169850).
* Fri Mar  6 2020 nopower@suse.com
- Release ldb 2.1.1
  + Samba 4.11 and later give incorrect results for SCOPE_ONE
    searches; (bso#14270).
* Wed Jan 22 2020 david.mulder@suse.com
  ldb: Release ldb 2.0.8
  + Upgrade waf to version 2.0.18 to match the rest of Samba 4.11.x
    (bso#13846)
* Fri Jan 17 2020 dmulder@suse.com
- libldb1 fails to migrate to libldb2 when libldb2 version is less
  than libldb1 version; (bsc#1160341)
* Thu Dec 19 2019 nopower@suse.com
- Add obsolete ldb1 directive to baselibs.conf
* Thu Oct  3 2019 jmcdonough@suse.com
- Update to version 2.0.7
  + Robustness improvements against duplicate attributes in ldb_filter_attrs()
    (bso#13695)
  + Robustness improvements against invalid string DN values (bso#14049)
  + log database repack so users know what is happening (bso#14059)
  + add ldb_options_get
  + add "batch_mode" option.
  + Remove Python 2.x support except to build just the bare C library
  + Remove --extra-python (a build time mode to produce Python2 and Python3
    bindings at the same time)
  + Fix standalone build of ldb.
  + CVE-2019-3824 out of bounds read in wildcard compare (bso#13773)
* Thu Aug  1 2019 scabrero@suse.de
- Update to 1.5.5
  + LDAP_REFERRAL_SCHEME_OPAQUE was added to ldb_module.h; (bso#12478);
  + Skip @ records early in a search full scan; (bso#13893);
* Tue Mar  5 2019 dmulder@suse.com
- Update to 1.5.4
  + Fix standalone build of ldb.
  + C99 build fixes.
  + CVE-2019-3824 out of bounds read in wildcard compare (bug#13773)
- Update to 1.5.3
  + Avoid inefficient one-level searches (bug#13762)
  + The test api.py should not rely on order of entries in dict (bug#13772)
* Wed Feb  6 2019 dmulder@suse.com
- Update to 1.5.2
  + dirsync: Allow arbitrary length cookies (bug #13686)
  + The build uses python3 by default: --extra-python would take
    python2 now
  + To build with python2 only use:
    PYTHON=python2 ./configure
    PYTHON=python2 make
    PYTHON=python2 make install
* Mon Nov 12 2018 scabrero@suse.de
- Update to 1.4.3
  + Python: Ensure ldb.Dn can accept utf8 encoded unicode (bug 13616)
* Tue Sep 25 2018 scabrero@suse.de
- Update license to LGPL-3.0
* Fri Aug 17 2018 dmulder@suse.com
- Update to 1.4.2
  + Security fix for CVE-2018-1140 (NULL pointer de-reference, bug 13374)
  + Fix memory leaks and missing error checks (bug 13459, 13471, 13475)
- 1.4.1
  + add some missing return value checks
  + Fix several mem leaks in ldb_index ldb_search ldb_tdb (bug#13475)
  + ldb_tdb: Use mem_ctx and so avoid leak onto long-term memory
    on duplicated add. (bug#13471)
  + ldb: Fix memory leak on module context (bug#13459)
  + Refused build of Samba 4.8 with ldb 1.4 (bug #13519)
  + Prevent similar issues in the future at configure time (bug #13519)
- 1.4.0
  + New LMDB backend (experimental)
  + Comprehensive tests for index behaviour
  + Enforce transactions for writes
  + Enforce read lock use for all reads
  + Fix memory leak in paged_results module.
    We hold at most 10 outstanding paged result cookies
    (bug #13362)
  + Fix compiler warnings
  + Python3 improvements
  + Restore --disable-python build
  + Fix for performance regression on one-level searches
    (bug #13448)
  + Samba's subtree_rename could fail to rename some entries
    (bug #13452)
* Wed Aug 15 2018 dmulder@suse.com
- Add fix_ldb_mod_op_test.patch: Fix missing NULL terminator in
  ldb_mod_op_test testsuite
* Tue Aug 14 2018 dmulder@suse.com
- Update to 1.3.5
  + Security fix for CVE-2018-1140 (NULL pointer de-reference,
    bug #13374).
- 1.3.4
  + Fix memory leaks and missing error checks (bug #13459, #13471,
    [#13475]).
  + Fix fallback to full scan (performance regression) on
    one-level search (bug #13448).
  + Fix read corruption (missing results) during writes,
    particularly during a Samba subtree rename (bug #13452).
* Wed May 23 2018 jmcdonough@suse.com
- Update to 1.3.3
  + Fix failure to upgrade to the GUID index DB format; (bso#13306).
* Fri Mar 16 2018 jmcdonough@suse.com
- Update to 1.3.2;
  + Expose the SHOW_BINARY, ENABLE_TRACING and DONT_CREATE_DB flag
    constants in the python api.
  + Don't load LDB_MODULESDIR as a module file.
  + Fix binary data in debug log (bug #13185).
  + Intersect the index from SCOPE_ONELEVEL with the index for the
    search expression (bso#13191)
  + GUID Index support.
* Fri Feb  9 2018 scabrero@suse.com
- Update to 1.2.3; (bsc#1080545);
  + Performance regression in DNS server with introduction of DNS wildcard;
    (bso#13191);
* Mon Oct  2 2017 jengelh@inai.de
- Remove %%if guards for blocks that do not affect the build result.
  Fix RPM groups and summaries.
  Drop very old SUSE support. Replace old RPM macros by new
  constructs.
* Mon Sep 18 2017 scabrero@suse.com
- Update to 1.2.2
  + Bug #13017: Add ldb_ldif_message_redacted_string() to allow debug
    of redacted log messages, avoiding showing secret values
  + Bug #13015: Allow re-index of newer databases with binary GUID TDB keys
    (this officially removes support for re-index of the original
    pack format 0, rather than simply segfaulting).
  + Avoid memory allocation and so make modify of records in ldb_tdb faster
* Wed Jul 26 2017 scabrero@suse.com
- Update to 1.2.1
  + Bug #12882: Do not install _ldb_text.py if we have system libldb
  + Use libraries from build dir for testsuite
  + Bug #12900: Fix index out of bound in ldb_msg_find_common_values
* Wed Jul  5 2017 scabrero@suse.com
- Update to 1.2.0
  + handle one more LDB_FLAG_INTERNAL_DISABLE_SINGLE_VALUE_CHECK
    case in ldb_tdb
  + fix ldb_tdb locking (performance) problems
  + fix ldb_tdb search inconsistencies by adding
    read_[un]lock() hooks to the module stack
    (bug #12858)
  + add cmocka based tests for the locking issues
  + ldb_version.h provides LDB_VERSION_{MAJOR,MINOR,RELEASE} defines
  + protect ldb_modules.h from being used by Samba < 4.7
    Note: that this release (as well as 1.1.30 and 1.1.31)
    may cause problems for older applications, e.g. Samba
    See https://bugzilla.samba.org/show_bug.cgi?id=12859
* Mon Jul  3 2017 scabrero@suse.com
- Update to 1.1.31
  + let ldbdump parse the -i option
  + don't allow the reveal_internals control for ldbedit
  + only allow --show-binary for ldbsearch
  + don't let ldbsearch create non-existing files
  + fix ldb_tdb search inconsistencies
  + add cmocka based tests
  + provide an interface for improved indexing for callers
    like Samba, which will allow much better performance.
  + Makes ldb access to tdb:// databases use a private event context
    rather than the global event context passed in by the caller.
    This is because running other operations while locks are held
    or a search is being conducted is not safe.
  + Add efficient function to find duplicate values in ldb messages
    (this makes large multi-valued attributes in ldb_tdb more efficient)
- Add ldb-tests-do-not-override-lib-path.patch: Check if LD_LIBRARY_PATH
  and LDB_MODULES_PATH environment variables are set before overriding
  them.
* Tue Jan 24 2017 ddiss@suse.com
- Update to 1.1.29; (bsc#1032915).
  + add support for LDB_CONTROL_RECALCULATE_RDN_OID on ldb_modify()
  + Performance and memory consumption improvements
* Wed Sep 14 2016 jmcdonough@suse.com
- Update to 1.1.27
  + performance improvements
  + VLV control improvements
* Tue Mar 15 2016 lmuelle@suse.com
- Require talloc 2.1.6 at build-time; (bsc#954658).
* Tue Mar  8 2016 dimstar@opensuse.org
- Add ldb-python3.5-fix-soabi_name.patch: Do not change x86_64 to
  x86-64 when building with python 3.5.
* Sun Feb 21 2016 lmuelle@suse.com
- Avoid a file collision for non SUSE build targets; (bsc#966174).
* Wed Feb 17 2016 lmuelle@suse.com
- Update to 1.1.26; (bsc#954658).
  + let a timeout of -1 indicate no timeout for a given request
  + fix memory leaks in pyldb ldb.search()
  + build fixes
  + improve pyldb ldb.search() help message
  + add pyldb ldb.search_iterator() api
  + add LDB_ATTR_FLAG_FORCE_BASE64_LDIF as optional argument
    to ldb_schema_attribute_add()
  + add client support for LDB_CONTROL_DIRSYNC_EX
* Fri Feb 12 2016 lmuelle@suse.com
- Provide python-ldb and python-ldb-devel; (bsc#966523).
* Wed Jan 27 2016 lmuelle@suse.com
- Update to 1.1.25; (bsc#954658).
  + torture: test ldb_unpack_data_only_attr_list
  + increment version due to added ldb_unpack_data_only_attr_list
  + introduce ldb_unpack_data_withlist to unpack partial list of attributes
* Thu Dec 10 2015 lmuelle@suse.com
- Update to 1.1.24.
  + fix LDAP \00 search expression attack DoS; CVE-2015-3223; (bso#11325)
  + fix remote read memory exploit in LDB; CVE-2015-5330; (bso#11599)
  + move ldb_(un)pack_data into ldb_module.h for testing
  + fix installation of _ldb_text.py
  + fix propagation of LDB errors through TDB
  + fix bug triggered by having an empty message in database during search
* Wed Nov 11 2015 lmuelle@suse.com
- Update to 1.1.23; (bsc#954658).
  + Test improvements
  + Improved python3 bindings; (bsc#951911)
  + Minor build fixes
* Fri Oct 30 2015 lmuelle@suse.com
- Add doxygen at build time to add the development documentation.
- Disable rpath-install and silent-rules while configure.
* Thu Oct 22 2015 lmuelle@suse.com
- Rename pyldb to python-ldb.
* Mon Sep  7 2015 lmuelle@suse.com
- Move the ldb-cmdline library to the ldb-tools package as the packaged
  binaries depend on it.
* Mon Sep  7 2015 lmuelle@suse.com
- Update the Samba Library Distribution Key file 'ldb.keyring'; (bso#945116).
* Wed Jul 22 2015 lmuelle@suse.com
- Update to 1.1.21; (bsc#939050).
  + build fixes
  + improved python bindings
* Sun Mar  1 2015 lmuelle@suse.com
- Update to 1.1.20.
  + validate_ldb of String(Generalized-Time) does not accept millisecond
    format ".000Z"; (bso#9810)
  + fix logic in ldb_val_to_time()
* Tue Jan 13 2015 lmuelle@suse.com
- Update to 1.1.19.
  + Allow to register extended match rules
* Sun Dec 21 2014 lmuelle@suse.com
- Update to 1.1.18.
  + fixes for segfaults in pyldb
  + documentation fixes
  + build system improvements
  + fix a typo in the comment, LDB_FLAGS_MOD_xxx -> LDB_FLAG_MOD_xxx
  + Fix check for third_party
  + make the successful ldb_transaction_start() message clearer
  + ldb-samba: fix a memory leak in ldif_canonicalise_objectCategory()
  + ldb-samba: Move pyldb-utils dependency to python_samba__ldb
  + build: improve detection of srcdir
* Thu Nov  6 2014 lmuelle@suse.com
- Use the upstream tar ball, as signature verification is now able to handle
  compressed archives.
* Tue Oct 28 2014 lmuelle@suse.com
- Remove dependency on gpg-offline as signature checking is implemented in the
  source validator.
* Tue Sep 23 2014 lmuelle@suse.com
- BuildRequire docbook-xsl-stylesheets and libxslt to process the man pages.
* Fri May 23 2014 lmuelle@suse.com
- Require pkg-config from the devel sub packages and do not BuildRequire it
  from libldb.
* Mon May  5 2014 lmuelle@suse.com
- Update to 1.1.17.
  + pyldb: add some more helper functions for LdbDn
  + pyldb: fix doc string for set_extended_component()
  + pyldb: add some const to PyObject_FromLdbValue()
  + Add a env variable to disable RTLD_DEEPBIND.
  + ldb_ildap: Map some wrong username/password errors on to
    LDB_ERR_INVALID_CREDENTIALS
  + pass module init errors back to the caller
  + Return LDB_ERR_INSUFFICIENT_ACCESS_RIGHTS rather than OPERATIONS_ERROR on
    EACCES and EPERM
  + Fix 1138330 Dereference null return value
  + bad if test in ldb_comparison_fold()
  + use of NULL pointer bugfix
  + Fix CID 241329 Array compared against 0
  + Fix CID 240798 Uninitialized pointer read
  + rdn_name: reject 'distinguishedName' depending of the MOD flags
  + Show the type of failing operation in default error message
  + Do not build libldb-cmdline when using system ldb.
  + ldb_map: Fix CID 1034791 Dereference null return value
  + Fix a const warning
* Fri Dec  6 2013 lmuelle@suse.com
- Verify source tar ball gpg signature.
* Thu Aug 29 2013 lmuelle@suse.com
- Consolidate python files in independent pyldb subpackages.
- Add pyldb to baselibs.conf.
* Tue Jul  2 2013 lmuelle@suse.com
- Update to 1.1.16.
  + Bump version to allow a depencency on the substring crash fix.
  + Cope with substring match with no chunks in ldb_filter_from_tree().
  + Ensure not to segfault on a filter such as (mail=).
  + Add missing dependency on replace for ldb.
  + Add more data test data for one level test cases.
  + Add tests for the python api.
  + Add more tests related to onelevel search.
  + Use strncmp instead of strcmp when comparing the val part.
  + Make test output more readable.
* Wed Feb  6 2013 lmuelle@suse.com
- Update to 1.1.15.
  + Ensure to decrement the transaction_active whenever we delete
    a transaction.
  + Move doxygen comments for ldb_connect to the right place.
* Sun Dec  2 2012 lmuelle@suse.com
- Update to 1.1.14.
  + fixed callers for ldb_pack_data() and ldb_unpack_data()
  + move ldb_pack.c into common
  + Add ldbdump, based on tdbdump
  + Remove no-longer-existing ltdb_unpack_data_free from ldb_tdb.h
  + Change ltdb_unpack_data to take an ldb_context
- Update to 1.1.13.
  + Don't use "isprint" in ldb_binary_encode(); (bso#9147).
* Mon Sep  3 2012 lmuelle@suse.com
- Update to 1.1.12.
  + Avoid printing secret attributes in ldb trace logs
* Thu Aug 30 2012 lmuelle@suse.com
- Update to 1.1.11.
  + LDB:ldb_tdb.c - deny multi-valued attributes manipulation with doublets
  + LDB:ldbsearch - add search filter tests
  + LDB:ldbsearch - search filters do not only contain "="
  + lib/ldb: Use tdb_parse_record and a callback rather than tdb_fetch()
- BuildRequire tevent version >= 0.9.17.
* Thu Aug 16 2012 lmuelle@suse.com
- Remove superfluous ldb-tools rpmlintrc file.
* Thu Aug  9 2012 lmuelle@suse.com
- Update to 1.1.10.
  + Enhancements and fixes to the s3 read, sesssetup, and server functions
  + s3: Fix a crash in reply_lockingX_error
  + s3:libsmb, smbd, and s4:libcli: add EXTENDED_SIGNATURE support in tcon
  + s3:rpc_server: make usage of session_extract_session_key()
  + s3:smb2_*: make use of SMBD_SMB2_*()
  + s4 and libcli: enahncements and fixes
* Tue Aug  7 2012 lmuelle@suse.com
- Update to 1.1.9.
  + Ensure rename target does not exist before deleting old record.
  + Add parameter to avoid NULL format string flagged by -Werror=format.
- Update to 1.1.8.
  + Fixes for pyldb.
  + Drop support for tdb_compat.
- BuildRequire pytalloc-devel.
* Thu Jun 28 2012 lmuelle@suse.com
- Disable rpath while configure.
* Wed Jun 13 2012 ddiss@suse.com
- Tag GPL-3.0+ based on tdb license; (bnc#765270).
* Sun Jun  3 2012 lmuelle@suse.com
- Define library name and use it instead of libldb1.
* Sun Jun  3 2012 lmuelle@suse.com
- Add missing post, postun, and files part to the libldb1 package.
* Sat Jun  2 2012 lmuelle@suse.com
- Rename package to ldb and add an independent libldb1 subpackage.
- Enhance and polish the package descriptions and summaries.
* Fri Jun  1 2012 lmuelle@suse.com
- BuildIgnore libtalloc to prevent a package conflict on Fedora systems.
* Fri Jun  1 2012 lmuelle@suse.com
- BuildRequire popt-devel.
* Thu May 31 2012 lmuelle@suse.com
- Define and use talloc, tdb, and tevent version macros.
- Define python_sitearch if undefined.
* Thu May 31 2012 lmuelle@suse.com
- BuildRequire libtalloc-devel, libtdb-devel, and libtevent-devel.
- Configure with bundled tdb2 library.
* Fri May 25 2012 lmuelle@suse.com
- Cleanup BuildRequires and spec file in general.
* Thu May 17 2012 lmuelle@suse.com
- BuildRequire libtalloc2-devel >= 2.0.7.
* Mon May 14 2012 lmuelle@suse.com
- BuildRequire libtalloc2-devel, libtdb1-devel, and libtevent0-devel.
- Adjust license string.
- Require libldb1 = %%{version} from the devel package.
* Wed Sep  7 2011 lars@samba.org
- Initial independent libldb1 package.
